summaryrefslogtreecommitdiff
path: root/quantum/joystick.h
diff options
context:
space:
mode:
authorJoel Challis <git@zvecr.com>2024-02-16 14:14:46 +0000
committerGitHub <noreply@github.com>2024-02-17 01:14:46 +1100
commit77e88674986ee14bd1799b1ab19b4c94af083bac (patch)
tree4e96ad9c0fd9cdefbe36e0b0045b6ba9896946e1 /quantum/joystick.h
parent13434fc066ef0b213587f773cc05f1c5b7d31113 (diff)
Fix joystick initialization (#22953)
Diffstat (limited to 'quantum/joystick.h')
-rw-r--r--quantum/joystick.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/quantum/joystick.h b/quantum/joystick.h
index 5de4ba66c6..5a69ceac64 100644
--- a/quantum/joystick.h
+++ b/quantum/joystick.h
@@ -52,24 +52,15 @@
#define JOYSTICK_MAX_VALUE ((1L << (JOYSTICK_AXIS_RESOLUTION - 1)) - 1)
-// configure on input_pin of the joystick_axes array entry to JS_VIRTUAL_AXIS
-// to prevent it from being read from the ADC. This allows outputing forged axis value.
-//
-#define JS_VIRTUAL_AXIS 0xFF
-
+// configure on input_pin of the joystick_axes array entry to NO_PIN
+// to prevent it from being read from the ADC. This allows outputting forged axis value.
#define JOYSTICK_AXIS_VIRTUAL \
- { JS_VIRTUAL_AXIS, JS_VIRTUAL_AXIS, JS_VIRTUAL_AXIS, 0, 1023 }
+ { NO_PIN, 0, JOYSTICK_MAX_VALUE / 2, JOYSTICK_MAX_VALUE }
#define JOYSTICK_AXIS_IN(INPUT_PIN, LOW, REST, HIGH) \
- { JS_VIRTUAL_AXIS, INPUT_PIN, JS_VIRTUAL_AXIS, LOW, REST, HIGH }
-#define JOYSTICK_AXIS_IN_OUT(INPUT_PIN, OUTPUT_PIN, LOW, REST, HIGH) \
- { OUTPUT_PIN, INPUT_PIN, JS_VIRTUAL_AXIS, LOW, REST, HIGH }
-#define JOYSTICK_AXIS_IN_OUT_GROUND(INPUT_PIN, OUTPUT_PIN, GROUND_PIN, LOW, REST, HIGH) \
- { OUTPUT_PIN, INPUT_PIN, GROUND_PIN, LOW, REST, HIGH }
+ { INPUT_PIN, LOW, REST, HIGH }
typedef struct {
- pin_t output_pin;
pin_t input_pin;
- pin_t ground_pin;
// the AVR ADC offers 10 bit precision, with significant bits on the higher part
uint16_t min_digit;
@@ -87,6 +78,14 @@ typedef struct {
extern joystick_t joystick_state;
+/**
+ * \brief Handle the initialization of the subsystem.
+ */
+void joystick_init(void);
+
+/**
+ * \brief Handle various subsystem background tasks.
+ */
void joystick_task(void);
/**
@@ -117,6 +116,9 @@ void unregister_joystick_button(uint8_t button);
*/
int16_t joystick_read_axis(uint8_t axis);
+/**
+ * \brief Sample and process the all axis.
+ */
void joystick_read_axes(void);
/**
@@ -127,6 +129,4 @@ void joystick_read_axes(void);
*/
void joystick_set_axis(uint8_t axis, int16_t value);
-void host_joystick_send(joystick_t *joystick);
-
/** \} */